#!/usr/local/bin/perl

use Parse::RecDescent;
use Device::ParallelPort::drv::parport;
use Device::ParallelPort;
use Time::HiRes qw( usleep ualarm gettimeofday tv_interval );

my $port = Device::ParallelPort->new('parport:0');
$port->set_byte (0,0);

my $nstep;
my $i;

sub ccw {
   $port->set_bit(3,1);
   return 0
}

sub cw {
   $port->set_bit(3,0);
   return 0
}

#
# 1 FULL STEP
# 0 HALF STEP
#
sub half_full {
   $port->set_bit(1,$_[0]);
}

sub step {
   $nstep=$_[0];
   for ($i=0; $i < $nstep; ++$i) {
      print ".";
      $port->set_bit(0,1);
      Time::HiRes::usleep 10000;  # 10 ms
      $port->set_bit(0,0);
   }
   print "\n"
}


#
my $rval = 9;
my $grammar =
q{

   Command  : ccw EOS
              {  print "CCW\n" ;
                 return ::ccw();
              }
            | cw EOS               
              {  print "CW\n" ;    
                 return ::cw();    
              }                     
            | exitcmd EOS
              { print "Exiting....\n"; exit }
            | step /[0-9]+/ EOS
              { print "STEP $item[2]\n";
                ::half_full (1);
                return ::step ($item[2]);
              }
           | half /[0-9]+/ EOS
             { print STEP "$item[1]\n"; 
               ::half_full (0);
               return ::step ($item[2]);
             }
            | <error>

              step        :    's'
              half        :    'h'
              ccw         :    'ccw'
              cw          :    'cw'
              exitcmd     :    'exit' 
              { print "Exiting\n" ; }
              EOS         :    /\Z/
};

my $parse = new Parse::RecDescent ($grammar);

print "> ";
while (<>) {
   $rval = $parse->Command($_);
   if (defined $rval) {
      print "$rval\n";
   }
   print "> ";
}



